==> autorequire-0.2.5.tgz: package/lib/loader_behavior/v0.5.2.js <==
(function() {
  var Module, path, vm;
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
  path = require('path');
  Module = require('module');
  vm = require('vm');
  module.exports = {
    _cleanContent: function(content) {
      return content.replace(/^\#\!.*/, '');
    },
    _buildRequire: function() {
      var require, self;
      self = this;
      require = __bind(function(path) {
        return this.require(path);
      }, this);
      require.resolve = function(request) {
        return Module._resolveFilename(request, self)[1];
      };
      Object.defineProperty(require, 'paths', {
        get: function() {
          throw new Error('require.paths is removed. Use node_modules folders, or the NODE_PATH environment variable instead.');
        }
      });
      require.main = process.mainModule;
      require.extensions = Module._extensions;
      require.registerExtension = function() {
        throw new Error('require.registerExtension() removed. Use require.extensions instead.');
      };
      require.cache = Module._cache;
      return require;
    },
    _buildSandbox: function(filename) {
      var k, sandbox, v;
      sandbox = vm.createContext({});
      for (k in global) {
        v = global[k];
        sandbox[k] = v;
      }
      sandbox.require = this._buildRequire();
      sandbox.exports = this.exports;
      sandbox.__filename = filename;
      sandbox.__dirname = path.dirname(filename);
      sandbox.module = this;
      sandbox.global = sandbox;
      sandbox.root = root;
      return sandbox;
    }
  };
}).call(this);

==> autorequire-0.2.6.tgz: package/lib/loader_behavior/v0.5.2.js <==
(function() {
  var Module, path, vm;
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
  path = require('path');
  Module = require('module');
  vm = require('vm');
  module.exports = {
    _cleanContent: function(content) {
      return content.replace(/^\#\!.*/, '');
    },
    _buildRequire: function() {
      var require, self;
      self = this;
      require = __bind(function(path) {
        return self.require(path);
      }, this);
      require.resolve = function(request) {
        return Module._resolveFilename(request, self)[1];
      };
      Object.defineProperty(require, 'paths', {
        get: function() {
          throw new Error('require.paths is removed. Use node_modules folders, or the NODE_PATH environment variable instead.');
        }
      });
      require.main = process.mainModule;
      require.extensions = Module._extensions;
      require.registerExtension = function() {
        throw new Error('require.registerExtension() removed. Use require.extensions instead.');
      };
      require.cache = Module._cache;
      return require;
    },
    _buildSandbox: function(filename) {
      var k, sandbox, v;
      sandbox = vm.createContext({});
      for (k in global) {
        v = global[k];
        sandbox[k] = v;
      }
      sandbox.require = this._buildRequire();
      sandbox.exports = this.exports;
      sandbox.__filename = filename;
      sandbox.__dirname = path.dirname(filename);
      sandbox.module = this;
      sandbox.global = sandbox;
      sandbox.root = root;
      return sandbox;
    }
  };
}).call(this);
